#[repr(u8)]pub enum Adco {
ADCO_0 = 0,
ADCO_1 = 1,
}Variants
ADCO_0 = 0
One conversion or one set of conversions if the hardware average function is enabled (AVGE=1) after initiating a conversion.
ADCO_1 = 1
Continuous conversions or sets of conversions if the hardware average function is enabled (AVGE=1) after initiating a conversion.
Implementations